@@ -1,3 +1,22 @@
+#!/usr/bin/env python
+#
+# Unofficial Instagram Python client. Built with the use of the selenium,
+# and requests modules.
+# Copyright (C) 2015-2021
+# David Henry Francis Wicker <wickerdevs@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser Public License for more details.
+#
+# You should have received a copy of the GNU Lesser Public License
+# along with this program.  If not, see [http://www.gnu.org/licenses/].
 """InstaClient class"""
 
 # IMPORT UTILITIES, DEPENDENCIES & MODELS
@@ -67,7 +86,9 @@ class InstaClient(Auth, Interactions, Scraper):
         """Checks whether the client is currently logged in to Instagram.
         A client is considered to be logged in if either a password and 
         username are provided to the client or if the client has the cookies
-        necessary to log into instagram.
+        necessary to log into instagram. If a specific cookie named 
+        ``sessionid`` is not present, the client will be considered to be
+        logged out.
 
         Returns:
             bool: True if `driver` is open and user is logged into Instagram.
@@ -78,7 +99,9 @@ class InstaClient(Auth, Interactions, Scraper):
                 if 'https://www.instagram.com' in url and ClientUrls.LOGIN_URL not in url:
                     return True
             elif self.session_cookies:
-                return True
+                for cookie in self.session_cookies:
+                    if cookie.get('name') == 'sessionid':
+                        return True
         return False
 
     @property
