@@ -1,3 +1,22 @@
+#!/usr/bin/env python
+#
+# Unofficial Instagram Python client. Built with the use of the selenium,
+# and requests modules.
+# Copyright (C) 2015-2021
+# David Henry Francis Wicker <wickerdevs@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser Public License for more details.
+#
+# You should have received a copy of the GNU Lesser Public License
+# along with this program.  If not, see [http://www.gnu.org/licenses/].
 from instaclient.client.constants import QueryHashes
 import json, requests
 
@@ -67,15 +86,17 @@ class Scraper(Component):
         return notifications
 
 
-    @Component._login_required
-    def get_profile(self:'InstaClient', username:str, context:bool=True) -> Optional['Profile']:
+    #@Component._login_required
+    def get_profile(self:'InstaClient', username:str, context:bool=False) -> Optional['Profile']:
         
-        if context and not self.logged_in and None not in (self.username, self.password):
+        if context and not self.logged_in:
+            if None in (self.username, self.password):
+                raise NotLoggedInError()
             self.login(self.username, self.password)
-        data = self._request(GraphUrls.GRAPH_USER.format(username), use_driver=True)
+        data = self._request(GraphUrls.GRAPH_USER.format(username), use_driver=context)
 
         if not data:
-            if ClientUrls.LOGIN_URL in self.driver.current_url:
+            if self.driver and (ClientUrls.LOGIN_URL in self.driver.current_url) or not self.driver:
                 raise NotLoggedInError()
             return None
 
@@ -119,12 +140,14 @@ class Scraper(Component):
             raise InvalidInstaSchemaError(__name__)
 
     
-    @Component._driver_required
-    def get_post(self:'InstaClient', shortcode:str, context:bool=True) -> Optional['Post']:
-        if context and not self.logged_in and None not in (self.username, self.password):
+    #@Component._driver_required
+    def get_post(self:'InstaClient', shortcode:str, context:bool=False) -> Optional['Post']:
+        if context and not self.logged_in:
+            if None in (self.username, self.password):
+                raise NotLoggedInError()
             self.login(self.username, self.password)
 
-        data = self._request(GraphUrls.GRAPH_POST.format(shortcode), use_driver=True)
+        data = self._request(GraphUrls.GRAPH_POST.format(shortcode), use_driver=context)
         if not data:
             raise InvalidInstaRequestError(GraphUrls.GRAPH_POST.format(shortcode))
 
@@ -1120,7 +1143,7 @@ class Scraper(Component):
                 }
                 result = requests.get(url, proxies=proxyDict)
             else:
-                result = requests.get(url)
+                result = requests.get(url, headers={'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.96 Safari/537.36 Edg/88.0.705.56'})
 
             try:
                 return result.json()
@@ -1134,7 +1157,4 @@ class Scraper(Component):
                 source = element.text
                 return json.loads(source)
             except:
-                return None
-
-
-    
\ No newline at end of file
+                return None
\ No newline at end of file
